==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/GetApplicationPackagePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the Batch account.
 * @property applicationName The name of the application. This must be unique within the account.
 * @property resourceGroupName The name of the resource group that contains the Batch account.
 * @property versionName The version of the application.
 */
public data class GetApplicationPackagePlainArgs(
    public val accountName: String,
    public val applicationName: String,
    public val resourceGroupName: String,
    public val versionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs =
        com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .applicationName(applicationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .versionName(versionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetApplicationPackagePlainArgs].
 */
@PulumiTagMarker
public class GetApplicationPackagePlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var applicationName: String? = null

    private var resourceGroupName: String? = null

    private var versionName: String? = null

    /**
     * @param value The name of the Batch account.
     */
    @JvmName("lmtximmsyxklattq")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the application. This must be unique within the account.
     */
    @JvmName("moqnvhwkyctkghlh")
    public suspend fun applicationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationName = mapped
    }

    /**
     * @param value The name of the resource group that contains the Batch account.
     */
    @JvmName("utlogrdnmxdrlfmb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The version of the application.
     */
    @JvmName("sxgtnfrupgxfiivq")
    public suspend fun versionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.versionName = mapped
    }

    internal fun build(): GetApplicationPackagePlainArgs = GetApplicationPackagePlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        applicationName = applicationName ?: throw PulumiNullFieldException("applicationName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        versionName = versionName ?: throw PulumiNullFieldException("versionName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/GetApplicationPackagePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the Batch account.
 * @property applicationName The name of the application. This must be unique within the account.
 * @property resourceGroupName The name of the resource group that contains the Batch account.
 * @property versionName The version of the application.
 */
public data class GetApplicationPackagePlainArgs(
    public val accountName: String,
    public val applicationName: String,
    public val resourceGroupName: String,
    public val versionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs =
        com.pulumi.azurenative.batch.inputs.GetApplicationPackagePlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .applicationName(applicationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .versionName(versionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetApplicationPackagePlainArgs].
 */
@PulumiTagMarker
public class GetApplicationPackagePlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var applicationName: String? = null

    private var resourceGroupName: String? = null

    private var versionName: String? = null

    /**
     * @param value The name of the Batch account.
     */
    @JvmName("hpxfsuyryxkrefjg")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the application. This must be unique within the account.
     */
    @JvmName("vnryonlopmssigrg")
    public suspend fun applicationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationName = mapped
    }

    /**
     * @param value The name of the resource group that contains the Batch account.
     */
    @JvmName("qanurrsbabhxbvib")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The version of the application.
     */
    @JvmName("iqkqorqftqljqqux")
    public suspend fun versionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.versionName = mapped
    }

    internal fun build(): GetApplicationPackagePlainArgs = GetApplicationPackagePlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        applicationName = applicationName ?: throw PulumiNullFieldException("applicationName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        versionName = versionName ?: throw PulumiNullFieldException("versionName"),
    )
}
